@@ -2,9 +2,14 @@ package Apache::Singleton;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.04';
+$VERSION = '0.05';
 
-require Apache::Singleton::Request;
+BEGIN {
+    my $delegator = sprintf 'Apache::Singleton::%s',
+	$ENV{MOD_PERL} ? 'Request' : 'Process';
+    eval qq{require $delegator};
+    sub _delegator { $delegator }
+}
 
 sub instance {
     my $class = shift;
@@ -21,15 +26,17 @@ sub _new_instance {
     bless {}, shift;
 }
 
-# Abstract methods, but default is Request ;)
+# Abstract methods, but compatible default
 sub _get_instance {
     my $class = shift;
-    $class->Apache::Singleton::Request::_get_instance(@_);
+    my $delegate = sprintf '%s::_get_instance', $class->_delegator;
+    $class->$delegate(@_);
 }
 
 sub _set_instance {
     my $class = shift;
-    $class->Apache::Singleton::Request::_set_instance(@_);
+    my $delegate = sprintf '%s::_set_instance', $class->_delegator;
+    $class->$delegate(@_);
 }
 
 1;
@@ -42,9 +49,11 @@ Apache::Singleton - Singleton class for mod_perl
 =head1 SYNOPSIS
 
   package Printer;
+  # default:
+  #   Request for mod_perl env
+  #   Process for non-mod_perl env
   use base qw(Apache::Singleton);
 
-  # same: default is per Request
   package Printer::PerRequest;
   use base qw(Apache::Singleton::Request);
 
@@ -68,16 +77,19 @@ you can change the scope of your object.
   use base qw(Apache::Singleton::Request);
 
 One instance for one request. Apache::Singleton will remove instance
-on each request. Implemented using mod_perl C<pnotes> API. This is the
-default scope, so inheriting from Apache::Singleton would do the same
-effect.
+on each request. Implemented using mod_perl C<pnotes> API. In mod_perl
+environment (where C<$ENV{MOD_PERL}> is defined), this is the default
+scope, so inheriting from Apache::Singleton would do the same effect.
 
 =item Process
 
   use base qw(Apache::Singleton::Process);
 
 One instance for one httpd process. Implemented using package
-global. Notice this is the same beaviour with Class::Singleton ;)
+global. In non-mod_perl environment, this is the default scope, and
+you may notice this is the same beaviour with Class::Singleton ;)
+
+So you can use this module safely under non-mod_perl environment.
 
 =back
 
@@ -86,7 +98,7 @@ global. Notice this is the same beaviour with Class::Singleton ;)
 Original idea by Matt Sergeant E<lt>matt@sergeant.orgE<gt> and Perrin
 Harkins E<lt>perrin@elem.comE<gt>.
 
-Code by Tatsuhiko Miyagawa E<lt>miyagawa@bulknews.netE<gt>
+Code by Tatsuhiko Miyagawa E<lt>miyagawa@bulknews.netE<gt>.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
